#!/bin/bash
# Copyright (C) 1999-2015 Parallels IP Holdings GmbH
# Copyright (c) 2018, vt@altlinux.org
#
# This file is part of OpenVZ libraries. OpenVZ is free software; you can
# redistribute it and/or modify it under the terms of the GNU Lesser General
# Public License as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels IP Holdings GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#
# This script deletes IP alias(es) inside VPS for RedHat like systems.
#
# Parameters are passed in environment variables.
# Required parameters:
#   IP_ADDR       - IPs to delete, several addresses should be divided by space
# Optional parameters:
#   IPDELALL      - delete all ip addresses
VENET_DEV=venet0
IFCFG=/etc/net/ifaces/${VENET_DEV}

# Function to delete IP address for RedHat like systems
function del_ip()
{
	local ipm ip mask

	[ -d ${IFCFG} ] || return 0
	for ipm in ${IP_ADDR}; do
		ip=${ipm%%/*}
		mask=
		if [[ "${ipm}" =~ / ]]; then
			mask=${ipm##*/}
		fi
		ipe=$(echo $ip | sed -e 's/[]\/$*.^[]/\\&/g')
		if is_ipv6 "${ip}"; then
			sed -i "/^$ipe\//d" ${IFCFG}/ipv6address
		else
			sed -i "/^$ipe\//d" ${IFCFG}/ipv4address
		fi
		if [ ! -s ${IFCFG}/ipv6address ]; then
			rm -f ${IFCFG}/ipv6address
			rm -f ${IFCFG}/ipv6route
			del_param ${IFCFG}/options CONFIG_IPV6
		fi
	done

	ifdown ${VENET_DEV} 2>/dev/null
	ifup ${VENET_DEV} 2>/dev/null
}

del_ip
exit 0
